@@ -392,7 +392,9 @@ tt_to_tlgrtf <- function(
     tt <- as_listing(
       df,
       key_cols = get_keycols(tt),
-      disp_cols = listing_dispcols(tt)
+      disp_cols = listing_dispcols(tt),
+      main_title = attr(tt, "main_title"),
+      main_footer = attr(tt, "main_footer")
     )
   }
 
@@ -514,6 +516,7 @@ tt_to_tlgrtf <- function(
           border_mat = pag_bord_mats[[i]],
           round_type = round_type,
           alignments = alignments,
+          label_width_ins = label_width_ins,
           ...
         )
       }
@@ -538,6 +541,7 @@ tt_to_tlgrtf <- function(
           border_mat = pag_bord_mats,
           round_type = round_type,
           alignments = alignments,
+          label_width_ins = label_width_ins,
           ...
         )
       } else if (!is.null(file)) { # only one page after pagination
