@@ -1,11 +1,8 @@
-library(tibble)
-library(dplyr)
-
-if (requireNamespace("rbmi", quietly = TRUE)) {
-  suppressPackageStartupMessages(library(rbmi))
-} else {
-  skip("rbmi package not available")
-}
+suppressPackageStartupMessages({
+  library(tibble)
+  library(dplyr)
+  library(rbmi)
+})
 
 f2n <- function(x) as.numeric(x) - 1
 
